@@ -940,7 +940,11 @@ func FunctionMap() map[string]physical.FunctionDetails {
 						if ts[1].TypeID != octosql.TypeIDInt {
 							return octosql.Type{}, false
 						}
-						return octosql.TypeSum(*ts[0].List.Element, octosql.Null), true
+						outType := octosql.Null
+						if elType := ts[0].List.Element; elType != nil {
+							outType = octosql.TypeSum(outType, *elType)
+						}
+						return outType, true
 					},
 					Strict: true,
 					Function: func(values []octosql.Value) (octosql.Value, error) {
