@@ -306,8 +306,17 @@ func (t *Transformers) TransformExpr(expr Expression) Expression {
 			Type:           expr.Type,
 			ExpressionType: expr.ExpressionType,
 			Cast: &Cast{
-				Expression: t.TransformExpr(expr.Cast.Expression),
-				TargetType: expr.Cast.TargetType,
+				Expression:   t.TransformExpr(expr.Cast.Expression),
+				TargetTypeID: expr.Cast.TargetTypeID,
+			},
+		}
+	case ExpressionTypeObjectFieldAccess:
+		out = Expression{
+			Type:           expr.Type,
+			ExpressionType: expr.ExpressionType,
+			ObjectFieldAccess: &ObjectFieldAccess{
+				Object: t.TransformExpr(expr.ObjectFieldAccess.Object),
+				Field:  expr.ObjectFieldAccess.Field,
 			},
 		}
 	default:
